@@ -245,7 +245,7 @@ describe 'glance::registry' do
 
   describe 'on unknown platforms' do
     let :facts do
-      { :osfamily => 'unknown' }
+      OSDefaults.get_facts({ :osfamily => 'unknown' })
     end
     let(:params) { default_params }
 
